package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ProposalInfo;

/**
 * 提案信息Mapper接口
 * 
 * @author boman
 * @date 2024-03-07
 */
public interface ProposalInfoMapper 
{
    /**
     * 查询提案信息
     * 
     * @param proposalId 提案信息主键
     * @return 提案信息
     */
    public ProposalInfo selectProposalInfoByProposalId(Long proposalId);

    /**
     * 查询提案信息列表
     * 
     * @param proposalInfo 提案信息
     * @return 提案信息集合
     */
    public List<ProposalInfo> selectProposalInfoList(ProposalInfo proposalInfo);

    /**
     * 新增提案信息
     * 
     * @param proposalInfo 提案信息
     * @return 结果
     */
    public int insertProposalInfo(ProposalInfo proposalInfo);

    /**
     * 修改提案信息
     * 
     * @param proposalInfo 提案信息
     * @return 结果
     */
    public int updateProposalInfo(ProposalInfo proposalInfo);

    /**
     * 删除提案信息
     * 
     * @param proposalId 提案信息主键
     * @return 结果
     */
    public int deleteProposalInfoByProposalId(Long proposalId);

    /**
     * 批量删除提案信息
     * 
     * @param proposalIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProposalInfoByProposalIds(Long[] proposalIds);

    List<ProposalInfo> selectProposalInfoListByUser(ProposalInfo proposalInfo);

    List<ProposalInfo> selectProposalInfoListByUnit(ProposalInfo proposalInfo);
}
